#[repr(C, align(32))]pub struct i8x32<S: Simd> {
pub(crate) val: S::i8x32,
pub simd: S,
}Expand description
A SIMD vector of 32 i8 elements.
You may construct this vector type using the Self::splat, Self::from_slice, Self::simd_from, Self::from_fn, and Self::block_splat methods.
fn construct_simd<S: Simd>(simd: S) {
// From a single scalar value:
let a = i8x32::splat(simd, 1);
let b = i8x32::simd_from(simd, 1);
// From a slice:
let c = i8x32::from_slice(simd, &[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32]);
// From an array:
let d = i8x32::simd_from(simd, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32]);
// From an element-wise function:
let e = i8x32::from_fn(simd, |i| i as i8);
// From `Self::Block`:
let f = i8x32::block_splat(i8x16::simd_from(simd, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]));
}Fields
val: S::i8x32simd: STrait Implementations
Sourceimpl<S: Simd> AddAssign<i8> for i8x32<S>
impl<S: Simd> AddAssign<i8> for i8x32<S>
Sourcefn add_assign(&mut self, rhs: i8)
fn add_assign(&mut self, rhs: i8)
+= operation. Read moreSourceimpl<S: Simd> AddAssign for i8x32<S>
impl<S: Simd> AddAssign for i8x32<S>
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Add two vectors element-wise, wrapping on overflow.
Sourceimpl<S: Simd> BitAndAssign<i8> for i8x32<S>
impl<S: Simd> BitAndAssign<i8> for i8x32<S>
Sourcefn bitand_assign(&mut self, rhs: i8)
fn bitand_assign(&mut self, rhs: i8)
&= operation. Read moreSourceimpl<S: Simd> BitAndAssign for i8x32<S>
impl<S: Simd> BitAndAssign for i8x32<S>
Sourcefn bitand_assign(&mut self, rhs: Self)
fn bitand_assign(&mut self, rhs: Self)
Compute the bitwise AND of two vectors.
Sourceimpl<S: Simd> BitOrAssign<i8> for i8x32<S>
impl<S: Simd> BitOrAssign<i8> for i8x32<S>
Sourcefn bitor_assign(&mut self, rhs: i8)
fn bitor_assign(&mut self, rhs: i8)
|= operation. Read moreSourceimpl<S: Simd> BitOrAssign for i8x32<S>
impl<S: Simd> BitOrAssign for i8x32<S>
Sourcefn bitor_assign(&mut self, rhs: Self)
fn bitor_assign(&mut self, rhs: Self)
Compute the bitwise OR of two vectors.
Sourceimpl<S: Simd> BitXorAssign<i8> for i8x32<S>
impl<S: Simd> BitXorAssign<i8> for i8x32<S>
Sourcefn bitxor_assign(&mut self, rhs: i8)
fn bitxor_assign(&mut self, rhs: i8)
^= operation. Read moreSourceimpl<S: Simd> BitXorAssign for i8x32<S>
impl<S: Simd> BitXorAssign for i8x32<S>
Sourcefn bitxor_assign(&mut self, rhs: Self)
fn bitxor_assign(&mut self, rhs: Self)
Compute the bitwise XOR of two vectors.
Sourceimpl<S: Simd> Bytes for i8x32<S>
impl<S: Simd> Bytes for i8x32<S>
Sourceimpl<S: Simd> MulAssign<i8> for i8x32<S>
impl<S: Simd> MulAssign<i8> for i8x32<S>
Sourcefn mul_assign(&mut self, rhs: i8)
fn mul_assign(&mut self, rhs: i8)
*= operation. Read moreSourceimpl<S: Simd> MulAssign for i8x32<S>
impl<S: Simd> MulAssign for i8x32<S>
Sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Multiply two vectors element-wise, wrapping on overflow.
Sourceimpl<S: Simd> Shl for i8x32<S>
impl<S: Simd> Shl for i8x32<S>
Sourcefn shl(self, rhs: Self) -> Self::Output
fn shl(self, rhs: Self) -> Self::Output
Shift each element left by the given number of bits.
Bits shifted out of the left side are discarded, and zeros are shifted in on the right.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> ShlAssign<u32> for i8x32<S>
impl<S: Simd> ShlAssign<u32> for i8x32<S>
Sourcefn shl_assign(&mut self, rhs: u32)
fn shl_assign(&mut self, rhs: u32)
<<= operation. Read moreSourceimpl<S: Simd> ShlAssign for i8x32<S>
impl<S: Simd> ShlAssign for i8x32<S>
Sourcefn shl_assign(&mut self, rhs: Self)
fn shl_assign(&mut self, rhs: Self)
Shift each element left by the given number of bits.
Bits shifted out of the left side are discarded, and zeros are shifted in on the right.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> Shr for i8x32<S>
impl<S: Simd> Shr for i8x32<S>
Sourcefn shr(self, rhs: Self) -> Self::Output
fn shr(self, rhs: Self) -> Self::Output
Shift each element right by the corresponding element in another vector.
For unsigned integers, zeros are shifted in on the left. For signed integers, the sign bit is replicated.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> ShrAssign<u32> for i8x32<S>
impl<S: Simd> ShrAssign<u32> for i8x32<S>
Sourcefn shr_assign(&mut self, rhs: u32)
fn shr_assign(&mut self, rhs: u32)
>>= operation. Read moreSourceimpl<S: Simd> ShrAssign for i8x32<S>
impl<S: Simd> ShrAssign for i8x32<S>
Sourcefn shr_assign(&mut self, rhs: Self)
fn shr_assign(&mut self, rhs: Self)
Shift each element right by the corresponding element in another vector.
For unsigned integers, zeros are shifted in on the left. For signed integers, the sign bit is replicated.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> SimdBase<S> for i8x32<S>
impl<S: Simd> SimdBase<S> for i8x32<S>
Sourceconst N: usize = 32
const N: usize = 32
Simd::f32s) and
want to process data in native-width chunks.Sourcetype Array = [i8; 32]
type Array = [i8; 32]
[Self::Element; Self::N]. It has the same layout as
this vector type, but likely has a lower alignment.fn as_slice(&self) -> &[i8]
fn as_mut_slice(&mut self) -> &mut [i8]
Sourcefn from_slice(simd: S, slice: &[i8]) -> Self
fn from_slice(simd: S, slice: &[i8]) -> Self
Sourcefn store_slice(&self, slice: &mut [i8])
fn store_slice(&self, slice: &mut [i8])
Sourcefn splat(simd: S, val: i8) -> Self
fn splat(simd: S, val: i8) -> Self
Sourcefn block_splat(block: Self::Block) -> Self
fn block_splat(block: Self::Block) -> Self
Sourcefn from_fn(simd: S, f: impl FnMut(usize) -> i8) -> Self
fn from_fn(simd: S, f: impl FnMut(usize) -> i8) -> Self
f with that element’s lane index (from 0 to
SimdBase::N - 1).Sourcefn slide_within_blocks<const SHIFT: usize>(
self,
rhs: impl SimdInto<Self, S>,
) -> Self
fn slide_within_blocks<const SHIFT: usize>( self, rhs: impl SimdInto<Self, S>, ) -> Self
slide, but operates independently on each 128-bit block.Sourceimpl<S: Simd> SimdCombine<S> for i8x32<S>
impl<S: Simd> SimdCombine<S> for i8x32<S>
Sourceimpl<S: Simd> SimdInt<S> for i8x32<S>
impl<S: Simd> SimdInt<S> for i8x32<S>
Sourcefn simd_eq(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_eq(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_lt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_lt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_le(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_le(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_ge(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_ge(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_gt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_gt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn zip_low(self, rhs: impl SimdInto<Self, S>) -> Self
fn zip_low(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn zip_high(self, rhs: impl SimdInto<Self, S>) -> Self
fn zip_high(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn unzip_low(self, rhs: impl SimdInto<Self, S>) -> Self
fn unzip_low(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn unzip_high(self, rhs: impl SimdInto<Self, S>) -> Self
fn unzip_high(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn interleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
fn interleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
Sourcefn deinterleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
fn deinterleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
Sourcefn min(self, rhs: impl SimdInto<Self, S>) -> Self
fn min(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn max(self, rhs: impl SimdInto<Self, S>) -> Self
fn max(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn to_float<T: SimdCvtFloat<Self>>(self) -> T
fn to_float<T: SimdCvtFloat<Self>>(self) -> T
SimdCvtFloat::float_from, and can only be called if there
actually exists a target type of the same bit width (currently, only f32).Sourceimpl<S: Simd> SubAssign<i8> for i8x32<S>
impl<S: Simd> SubAssign<i8> for i8x32<S>
Sourcefn sub_assign(&mut self, rhs: i8)
fn sub_assign(&mut self, rhs: i8)
-= operation. Read moreSourceimpl<S: Simd> SubAssign for i8x32<S>
impl<S: Simd> SubAssign for i8x32<S>
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Subtract two vectors element-wise, wrapping on overflow.