#[repr(C, align(64))]pub struct u32x16<S: Simd> {
pub(crate) val: S::u32x16,
pub simd: S,
}Expand description
A SIMD vector of 16 u32 elements.
You may construct this vector type using the Self::splat, Self::from_slice, Self::simd_from, Self::from_fn, and Self::block_splat methods.
fn construct_simd<S: Simd>(simd: S) {
// From a single scalar value:
let a = u32x16::splat(simd, 1);
let b = u32x16::simd_from(simd, 1);
// From a slice:
let c = u32x16::from_slice(simd, &[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]);
// From an array:
let d = u32x16::simd_from(simd, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]);
// From an element-wise function:
let e = u32x16::from_fn(simd, |i| i as u32);
// From `Self::Block`:
let f = u32x16::block_splat(u32x4::simd_from(simd, [1, 2, 3, 4]));
}Fields
val: S::u32x16simd: STrait Implementations
Sourceimpl<S: Simd> AddAssign<u32> for u32x16<S>
impl<S: Simd> AddAssign<u32> for u32x16<S>
Sourcefn add_assign(&mut self, rhs: u32)
fn add_assign(&mut self, rhs: u32)
+= operation. Read moreSourceimpl<S: Simd> AddAssign for u32x16<S>
impl<S: Simd> AddAssign for u32x16<S>
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Add two vectors element-wise, wrapping on overflow.
Sourceimpl<S: Simd> BitAndAssign<u32> for u32x16<S>
impl<S: Simd> BitAndAssign<u32> for u32x16<S>
Sourcefn bitand_assign(&mut self, rhs: u32)
fn bitand_assign(&mut self, rhs: u32)
&= operation. Read moreSourceimpl<S: Simd> BitAndAssign for u32x16<S>
impl<S: Simd> BitAndAssign for u32x16<S>
Sourcefn bitand_assign(&mut self, rhs: Self)
fn bitand_assign(&mut self, rhs: Self)
Compute the bitwise AND of two vectors.
Sourceimpl<S: Simd> BitOrAssign<u32> for u32x16<S>
impl<S: Simd> BitOrAssign<u32> for u32x16<S>
Sourcefn bitor_assign(&mut self, rhs: u32)
fn bitor_assign(&mut self, rhs: u32)
|= operation. Read moreSourceimpl<S: Simd> BitOrAssign for u32x16<S>
impl<S: Simd> BitOrAssign for u32x16<S>
Sourcefn bitor_assign(&mut self, rhs: Self)
fn bitor_assign(&mut self, rhs: Self)
Compute the bitwise OR of two vectors.
Sourceimpl<S: Simd> BitXorAssign<u32> for u32x16<S>
impl<S: Simd> BitXorAssign<u32> for u32x16<S>
Sourcefn bitxor_assign(&mut self, rhs: u32)
fn bitxor_assign(&mut self, rhs: u32)
^= operation. Read moreSourceimpl<S: Simd> BitXorAssign for u32x16<S>
impl<S: Simd> BitXorAssign for u32x16<S>
Sourcefn bitxor_assign(&mut self, rhs: Self)
fn bitxor_assign(&mut self, rhs: Self)
Compute the bitwise XOR of two vectors.
Sourceimpl<S: Simd> Bytes for u32x16<S>
impl<S: Simd> Bytes for u32x16<S>
Sourceimpl<S: Simd> MulAssign<u32> for u32x16<S>
impl<S: Simd> MulAssign<u32> for u32x16<S>
Sourcefn mul_assign(&mut self, rhs: u32)
fn mul_assign(&mut self, rhs: u32)
*= operation. Read moreSourceimpl<S: Simd> MulAssign for u32x16<S>
impl<S: Simd> MulAssign for u32x16<S>
Sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Multiply two vectors element-wise, wrapping on overflow.
Sourceimpl<S: Simd> Shl for u32x16<S>
impl<S: Simd> Shl for u32x16<S>
Sourcefn shl(self, rhs: Self) -> Self::Output
fn shl(self, rhs: Self) -> Self::Output
Shift each element left by the given number of bits.
Bits shifted out of the left side are discarded, and zeros are shifted in on the right.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> ShlAssign<u32> for u32x16<S>
impl<S: Simd> ShlAssign<u32> for u32x16<S>
Sourcefn shl_assign(&mut self, rhs: u32)
fn shl_assign(&mut self, rhs: u32)
<<= operation. Read moreSourceimpl<S: Simd> ShlAssign for u32x16<S>
impl<S: Simd> ShlAssign for u32x16<S>
Sourcefn shl_assign(&mut self, rhs: Self)
fn shl_assign(&mut self, rhs: Self)
Shift each element left by the given number of bits.
Bits shifted out of the left side are discarded, and zeros are shifted in on the right.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> Shr for u32x16<S>
impl<S: Simd> Shr for u32x16<S>
Sourcefn shr(self, rhs: Self) -> Self::Output
fn shr(self, rhs: Self) -> Self::Output
Shift each element right by the corresponding element in another vector.
For unsigned integers, zeros are shifted in on the left. For signed integers, the sign bit is replicated.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> ShrAssign<u32> for u32x16<S>
impl<S: Simd> ShrAssign<u32> for u32x16<S>
Sourcefn shr_assign(&mut self, rhs: u32)
fn shr_assign(&mut self, rhs: u32)
>>= operation. Read moreSourceimpl<S: Simd> ShrAssign for u32x16<S>
impl<S: Simd> ShrAssign for u32x16<S>
Sourcefn shr_assign(&mut self, rhs: Self)
fn shr_assign(&mut self, rhs: Self)
Shift each element right by the corresponding element in another vector.
For unsigned integers, zeros are shifted in on the left. For signed integers, the sign bit is replicated.
This operation is not implemented in hardware on all platforms. On WebAssembly, and on x86 platforms without AVX2, this will use a fallback scalar implementation.
Sourceimpl<S: Simd> SimdBase<S> for u32x16<S>
impl<S: Simd> SimdBase<S> for u32x16<S>
Sourceconst N: usize = 16
const N: usize = 16
Simd::f32s) and
want to process data in native-width chunks.Sourcetype Array = [u32; 16]
type Array = [u32; 16]
[Self::Element; Self::N]. It has the same layout as
this vector type, but likely has a lower alignment.fn as_slice(&self) -> &[u32]
fn as_mut_slice(&mut self) -> &mut [u32]
Sourcefn from_slice(simd: S, slice: &[u32]) -> Self
fn from_slice(simd: S, slice: &[u32]) -> Self
Sourcefn store_slice(&self, slice: &mut [u32])
fn store_slice(&self, slice: &mut [u32])
Sourcefn splat(simd: S, val: u32) -> Self
fn splat(simd: S, val: u32) -> Self
Sourcefn block_splat(block: Self::Block) -> Self
fn block_splat(block: Self::Block) -> Self
Sourcefn from_fn(simd: S, f: impl FnMut(usize) -> u32) -> Self
fn from_fn(simd: S, f: impl FnMut(usize) -> u32) -> Self
f with that element’s lane index (from 0 to
SimdBase::N - 1).Sourcefn slide_within_blocks<const SHIFT: usize>(
self,
rhs: impl SimdInto<Self, S>,
) -> Self
fn slide_within_blocks<const SHIFT: usize>( self, rhs: impl SimdInto<Self, S>, ) -> Self
slide, but operates independently on each 128-bit block.Sourceimpl<S: Simd> SimdCvtFloat<u32x16<S>> for f32x16<S>
impl<S: Simd> SimdCvtFloat<u32x16<S>> for f32x16<S>
Sourcefn float_from(x: u32x16<S>) -> Self
fn float_from(x: u32x16<S>) -> Self
Convert each unsigned 32-bit integer element to a floating-point value.
Values that cannot be exactly represented are rounded to the nearest representable value.
Sourceimpl<S: Simd> SimdCvtTruncate<f32x16<S>> for u32x16<S>
impl<S: Simd> SimdCvtTruncate<f32x16<S>> for u32x16<S>
Sourcefn truncate_from(x: f32x16<S>) -> Self
fn truncate_from(x: f32x16<S>) -> Self
Convert each floating-point element to an unsigned 32-bit integer, truncating towards zero.
Out-of-range values or NaN will produce implementation-defined results.
On x86 platforms, this operation will still be slower than converting to i32, because there is no native instruction for converting to u32 (at least until AVX-512, which is currently not supported).
If you know your values fit within range of an i32, you should convert to an i32 and cast to your desired datatype afterwards.
Sourcefn truncate_from_precise(x: f32x16<S>) -> Self
fn truncate_from_precise(x: f32x16<S>) -> Self
Convert each floating-point element to an unsigned 32-bit integer, truncating towards zero.
Out-of-range values are saturated to the closest in-range value. NaN becomes 0.
Sourceimpl<S: Simd> SimdInt<S> for u32x16<S>
impl<S: Simd> SimdInt<S> for u32x16<S>
Sourcefn simd_eq(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_eq(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_lt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_lt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_le(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_le(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_ge(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_ge(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn simd_gt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
fn simd_gt(self, rhs: impl SimdInto<Self, S>) -> Self::Mask
Sourcefn zip_low(self, rhs: impl SimdInto<Self, S>) -> Self
fn zip_low(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn zip_high(self, rhs: impl SimdInto<Self, S>) -> Self
fn zip_high(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn unzip_low(self, rhs: impl SimdInto<Self, S>) -> Self
fn unzip_low(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn unzip_high(self, rhs: impl SimdInto<Self, S>) -> Self
fn unzip_high(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn interleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
fn interleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
Sourcefn deinterleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
fn deinterleave(self, rhs: impl SimdInto<Self, S>) -> (Self, Self)
Sourcefn min(self, rhs: impl SimdInto<Self, S>) -> Self
fn min(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn max(self, rhs: impl SimdInto<Self, S>) -> Self
fn max(self, rhs: impl SimdInto<Self, S>) -> Self
Sourcefn to_float<T: SimdCvtFloat<Self>>(self) -> T
fn to_float<T: SimdCvtFloat<Self>>(self) -> T
SimdCvtFloat::float_from, and can only be called if there
actually exists a target type of the same bit width (currently, only f32).Sourceimpl<S: Simd> SubAssign<u32> for u32x16<S>
impl<S: Simd> SubAssign<u32> for u32x16<S>
Sourcefn sub_assign(&mut self, rhs: u32)
fn sub_assign(&mut self, rhs: u32)
-= operation. Read moreSourceimpl<S: Simd> SubAssign for u32x16<S>
impl<S: Simd> SubAssign for u32x16<S>
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Subtract two vectors element-wise, wrapping on overflow.